==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/rss.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");

$t = isset($_GET['t']) ? $_GET['t'] : "";
$c = isset($_GET['c']) ? $_GET['c'] : 20;
$o = isset($_GET['o']) ? "lastrdate" : "Repostamp";

$title = SqlResult("SELECT Topic FROM T_Topics WHERE Rid = '$t'");
if (empty($title)) $t = '';
$txt = make_body($t,$c,$o,$title);

if (!empty($txt)) {
	header ('Cache-Control: private, pre-check=0, post-check=0, max-age=0');
	header ('Expires: ' . gmdate('D, d M Y H:i:s', time()) . ' GMT');
	header ('Last-Modified: ' . gmdate('D, d M Y H:i:s') . ' GMT');
	header ('Content-Type: text/xml');
	echo $txt;
}

function make_body($topic='',$c,$o,$title='') {
	global $rdf_lang;

	if ($c > 50) $c = 50;
	$CONF = KWL_GetConf();
	$sql = "SELECT * FROM T_Stories WHERE Verified = 'Y'";
	if ($topic) $sql .= " AND Topic = $topic";
	$sql .= " ORDER BY $o DESC LIMIT $c";
   $result = SqlQuery($sql);

   if (!empty($title)) $url = $CONF['G_URL'] . "/stories.php?topic=$topic";
   else $url = $CONF['G_URL'];

   $ret = "<?xml version=\"1.0\" encoding=\"$rdf_lang\"?>\n\n".
      "<rss version=\"2.0\">\n\n".
      "<channel>\n".
      "\t<title>$CONF[SiteName]";
   if (!empty($title)) $ret .= " - " . htmlspecialchars($title);
   $ret .= "</title>\n".
      "\t<link>$url</link>\n".
      "\t<description>$CONF[SiteSlogan]</description>\n".
      "\t<language>$rdf_lang</language>\n\n";

   while($A = mysql_fetch_array($result)) {
      $description = trim(htmlspecialchars(eregi_replace("(\r*)\n","",KWL_ParseContent($A['Content'],3))));
      if ($o == "lastrdate") {
         $sql  = "SELECT Rid,ParentRid FROM T_Comments WHERE TopRid='$A[Rid]' ";
         $sql .= "ORDER by Birthstamp DESC LIMIT 1";
         $crid = SqlQueryFetchArray($sql);
         $link = "$CONF[G_URL]/comments.php?rid=$crid[ParentRid]&amp;story=$A[Rid]#$crid[Rid]";
      } else $link = KWL_MakeStoryLink($A['Rid']);
      $ret .= "\t<item>\n".
         "\t<title>". $A['Heading'] . "</title>\n".
         "\t<link>$link</link>\n".
         "\t<description>\n".
         "\t$description\n".
         "\t</description>\n".
			"\t<pubDate>". $A['Birthstamp'] . "</pubDate>\n";
		if (!empty($title)) $ret .= "\t<category>". htmlspecialchars($title) ."</category>\n";
		$ret .= "\t</item>\n\n";
   }
   $ret .= "</channel>\n</rss>\n";
	mysql_free_result($result);
   return $ret;
}
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/rss.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");

if (!$CONF['Backend']) die(_DISABLED);

$t = isset($_GET['t']) ? $_GET['t'] : "";
$c = isset($_GET['c']) ? $_GET['c'] : 20;
$o = isset($_GET['o']) ? "lastrdate" : "Repostamp";
$encoding = isset($_GET['enc']) ? $_GET['enc'] : "";


if (empty($_SERVER['QUERY_STRING'])) {
   $txt = KWL_ReadFile("{$CONF['G_PATH']}/backend/{$CONF['BackendFile']}");
} else {
   $title = SqlResult("SELECT Topic FROM T_Topics WHERE Rid = '$t'");
   if (empty($title)) $t = '';
   $txt = make_body($t,$c,$o,$title,$encoding);
}

if (!empty($txt)) {
	header ('Cache-Control: private, pre-check=0, post-check=0, max-age=0');
	header ('Expires: ' . gmdate('D, d M Y H:i:s', time()) . ' GMT');
	header ('Last-Modified: ' . gmdate('D, d M Y H:i:s') . ' GMT');
	header ('Content-Type: text/xml');
	echo $txt;
}

function make_body($topic='',$c,$o,$title='',$encoding='') {
	global $rdf_lang;

   if (function_exists("iconv") && $encoding) {
      if ($rdf_lang != $encoding) {
         $orig_enc = $rdf_lang;
         $rdf_lang = $encoding;
      }
   }

	if ($c > 50) $c = 50;
	$CONF = KWL_GetConf();
	$sql = "SELECT * FROM T_Stories WHERE Verified = 'Y'";
	if ($topic) $sql .= " AND Topic = $topic";
	$sql .= " ORDER BY $o DESC LIMIT $c";
   $result = SqlQuery($sql);

   if (!empty($title)) $url = $CONF['G_URL'] . "/stories.php?topic=$topic";
   else $url = $CONF['G_URL'];

   $ret = "<?xml version=\"1.0\" encoding=\"$rdf_lang\"?>\n\n".
      "<rss version=\"2.0\">\n\n".
"<!--
   Add \"t=n\" to specified topic(n) title.
   Add \"c=n\" to specify number(n) of title (max:50).
   Add \"o=1\" to get title sorted by lastest comment.
   Add \"enc=euc-kr\" or \"enc=utf-8\" to get specified charset.
-->\n\n".

      "<channel>\n".
      "\t<title>$CONF[SiteName]";
   if (!empty($title)) $ret .= " - " . htmlspecialchars($title);
   $ret .= "</title>\n".
      "\t<link>$url</link>\n".
      "\t<description>$CONF[SiteSlogan]</description>\n".
      "\t<language>$rdf_lang</language>\n\n";

   while($A = mysql_fetch_array($result)) {
      $description = KWL_ParseContent(KWL_StringCut($A['Content'],300),3);
      $description = htmlspecialchars(eregi_replace("(\r*)\n","",$description)) . "...";
      if ($o == "lastrdate") {
         $sql  = "SELECT Rid,ParentRid FROM T_Comments WHERE TopRid='$A[Rid]' ";
         $sql .= "ORDER by Birthstamp DESC LIMIT 1";
         $crid = SqlQueryFetchArray($sql);
         $link = "$CONF[G_URL]/comments.php?rid=$crid[ParentRid]&amp;story=$A[Rid]#$crid[Rid]";
      } else $link = KWL_MakeStoryLink($A['Rid']);
      $ret .= "\t<item>\n".
         "\t<title>". $A['Heading'] . "</title>\n".
         "\t<link>$link</link>\n".
         "\t<description>\n".
         "\t$description\n".
         "\t</description>\n".
			"\t<pubDate>". $A['Birthstamp'] . "</pubDate>\n";
		if (!empty($title)) $ret .= "\t<category>". htmlspecialchars($title) ."</category>\n";
		$ret .= "\t</item>\n\n";
   }
   $ret .= "</channel>\n</rss>\n";
	mysql_free_result($result);

   if (!empty($orig_enc)) {
      if ($orig_enc != $encoding) {
         $ret = @iconv($orig_enc,$encoding,$ret);
      }
   }
   
   return $ret;
}
?>
